@@ -1,4 +1,4 @@
-# $Header: /raid/cvsroot/DBIx/DBIx-SearchBuilder/SearchBuilder.pm,v 1.32 2001/09/26 20:21:40 jesse Exp $
+# $Header: /raid/cvsroot/DBIx/DBIx-SearchBuilder/SearchBuilder.pm,v 1.33 2001/10/02 23:54:42 jesse Exp $
 
 # {{{ Version, package, new, etc
 
@@ -7,7 +7,7 @@ package DBIx::SearchBuilder;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "0.43";
+$VERSION = "0.45";
 
 =head1 NAME
 
@@ -938,7 +938,7 @@ the alias generated by the join.
 
 sub Join {
     my $self = shift;
-    my %args = (TYPE => undef,
+    my %args = (TYPE => 'normal',
 		FIELD1 => undef,
 		ALIAS1 => undef,
 		FIELD2 => undef,
